==> dde-network-core_1.0.47.orig.tar.xz: dde-network-core-1.0.47/dss-network-plugin/translations/dss-network-plugin_pt.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="pt" version="2.1">
<context>
    <name>Bubble</name>
    <message>
        <source>1 new message</source>
        <translation>1 nova mensagem</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Connecting %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1 ligado</translation>
    </message>
    <message>
        <source>%1 disconnected</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to connect %1, please check your router or net cable.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to connect %1, please keep closer to the wireless router</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Connection failed, unable to connect %1, wrong password</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Password is required to connect %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The %1 802.11 WLAN network could not be found</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>dss::module::NetworkModule</name>
    <message>
        <source>Wired Connection</source>
        <translation>Ligação por cabo</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDetails</name>
    <message>
        <source>Hotspot</source>
        <translation>Ponto de Acesso</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Protocol</source>
        <translation>Protocolo</translation>
    </message>
    <message>
        <source>Security Type</source>
        <translation>Tipo de Segurança</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>Banda</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>Canal</translation>
    </message>
    <message>
        <source>Interface</source>
        <translation>Interface</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Máscara de rede</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Gateway</translation>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>DNS Principal</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Prefixo</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Velocidade</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDeviceRealize</name>
    <message>
        <source>Device disabled</source>
        <translation>Dispositivo desativado</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Ligado mas sem acesso à Internet</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Não ligado</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Cabo de rede desligado</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>A ligar</translation>
    </message>
    <message>
        <source>Authenticating</source>
        <translation>A autenticar</translation>
    </message>
    <message>
        <source>Obtaining IP address</source>
        <translation>A obter endereço de IP</translation>
    </message>
    <message>
        <source>Connected</source>
        <translation>Ligado</translation>
    </message>
    <message>
        <source>Disconnected</source>
        <translation>Desligado</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>Conflito de IP</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>Falha</translation>
    </message>
    <message>
        <source>Obtaining address</source>
        <translation>A obter endereço</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkProcesser</name>
    <message>
        <source>Wired Network</source>
        <translation>Rede por cabo</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>Rede por cabo %1</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Rede sem fios</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>Rede sem fios %1</translation>
    </message>
</context>
<context>
    <name>dde::networkplugin::NetworkPluginHelper</name>
    <message>
        <source>Device disabled</source>
        <translation>Dispositivo desativado</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Cabo de rede desligado</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Não ligado</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>A ligar</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Ligado mas sem acesso à Internet</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation>Falha na ligação</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>Conflito de IP</translation>
    </message>
    <message>
        <source>Disable wired connection</source>
        <translation>Desativar ligação por cabo</translation>
    </message>
    <message>
        <source>Enable wired connection</source>
        <translation>Ativar ligação por cabo</translation>
    </message>
    <message>
        <source>Disable wireless connection</source>
        <translation>Desativar ligação sem fios</translation>
    </message>
    <message>
        <source>Enable wireless connection</source>
        <translation>Ativar ligação sem fios</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>Desativar rede</translation>
    </message>
    <message>
        <source>Enable network</source>
        <translation>Ativar rede</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>Definições de rede</translation>
    </message>
</context>
</TS>

==> dde-network-core_1.0.57.orig.tar.xz: dde-network-core-1.0.57/dss-network-plugin/translations/dss-network-plugin_pt.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="pt" version="2.1">
<context>
    <name>Bubble</name>
    <message>
        <source>1 new message</source>
        <translation>1 nova mensagem</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Connecting %1</source>
        <translation>A conectar %1</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1 ligado</translation>
    </message>
    <message>
        <source>%1 disconnected</source>
        <translation>%1 disconectado</translation>
    </message>
    <message>
        <source>Unable to connect %1, please check your router or net cable.</source>
        <translation>Falha ao conectar %1, por favor verifique o seu router ou cabo internet.</translation>
    </message>
    <message>
        <source>Unable to connect %1, please keep closer to the wireless router</source>
        <translation>Falha ao conectar %1, por favor mantenha-se próximo do seu sinal wireless</translation>
    </message>
    <message>
        <source>Connection failed, unable to connect %1, wrong password</source>
        <translation>Falha de conexão, erro ao conectar %1, password errada</translation>
    </message>
    <message>
        <source>Password is required to connect %1</source>
        <translation>Uma password é necessária para conectar a %1</translation>
    </message>
    <message>
        <source>The %1 802.11 WLAN network could not be found</source>
        <translation>A rede WLAN %1 802.11 não pode ser encontrada</translation>
    </message>
</context>
<context>
    <name>dss::module::NetworkModule</name>
    <message>
        <source>Wired Connection</source>
        <translation>Ligação por cabo</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDetails</name>
    <message>
        <source>Hotspot</source>
        <translation>Ponto de Acesso</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Protocol</source>
        <translation>Protocolo</translation>
    </message>
    <message>
        <source>Security Type</source>
        <translation>Tipo de Segurança</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>Banda</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>Canal</translation>
    </message>
    <message>
        <source>Interface</source>
        <translation>Interface</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Máscara de rede</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Gateway</translation>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>DNS Principal</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Prefixo</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Velocidade</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDeviceRealize</name>
    <message>
        <source>Device disabled</source>
        <translation>Dispositivo desativado</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Ligado mas sem acesso à Internet</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Não ligado</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Cabo de rede desligado</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>A ligar</translation>
    </message>
    <message>
        <source>Authenticating</source>
        <translation>A autenticar</translation>
    </message>
    <message>
        <source>Obtaining IP address</source>
        <translation>A obter endereço de IP</translation>
    </message>
    <message>
        <source>Connected</source>
        <translation>Ligado</translation>
    </message>
    <message>
        <source>Disconnected</source>
        <translation>Desligado</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>Conflito de IP</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>Falha</translation>
    </message>
    <message>
        <source>Obtaining address</source>
        <translation>A obter endereço</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkProcesser</name>
    <message>
        <source>Wired Network</source>
        <translation>Rede por cabo</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>Rede por cabo %1</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Rede sem fios</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>Rede sem fios %1</translation>
    </message>
</context>
<context>
    <name>dde::networkplugin::NetworkPluginHelper</name>
    <message>
        <source>Device disabled</source>
        <translation>Dispositivo desativado</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Cabo de rede desligado</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Não ligado</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>A ligar</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Ligado mas sem acesso à Internet</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation>Falha na ligação</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>Conflito de IP</translation>
    </message>
    <message>
        <source>Disable wired connection</source>
        <translation>Desativar ligação por cabo</translation>
    </message>
    <message>
        <source>Enable wired connection</source>
        <translation>Ativar ligação por cabo</translation>
    </message>
    <message>
        <source>Disable wireless connection</source>
        <translation>Desativar ligação sem fios</translation>
    </message>
    <message>
        <source>Enable wireless connection</source>
        <translation>Ativar ligação sem fios</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>Desativar rede</translation>
    </message>
    <message>
        <source>Enable network</source>
        <translation>Ativar rede</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>Definições de rede</translation>
    </message>
</context>
</TS>
